@@ -1,7 +1,7 @@
 package Getopt::Long::Less;
 
 our $DATE = '2015-06-17'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -386,7 +386,7 @@ Getopt::Long::Less - Like Getopt::Long, but with less features
 
 =head1 VERSION
 
-This document describes version 0.05 of Getopt::Long::Less (from Perl distribution Getopt-Long-Less), released on 2015-06-17.
+This document describes version 0.06 of Getopt::Long::Less (from Perl distribution Getopt-Long-Less), released on 2015-06-17.
 
 =head1 DESCRIPTION
 
@@ -409,8 +409,8 @@ might be added in the future).
 
 No autoversion, no autohelp. No support to configure prefix pattern.
 
-Currently no support for arrayref handler (e.g. C<<"foo=s" => \@ary>>). No
-support for array desttype (C<<'foo=s@' => ...>>).
+Currently no support for arrayref handler (e.g. C<< "foo=s" => \@ary >>). No
+support for array desttype (C<< 'foo=s@' => ... >>).
 
 Also, this module requires 5.010.
 
@@ -420,15 +420,15 @@ milliseconds from startup overhead of my CLI scripts. That's it :-)
 
 Sample startup overhead benchmark:
 
-                       Rate     load_gl load_glless   perl
- load_gl      75.27+-0.33/s          --      -48.5% -88.5%
- load_glless 146.09+-0.54/s  94.1+-1.1%          -- -77.6%
- perl          652.8+-2.3/s 767.2+-4.9% 346.8+-2.3%     --
+                      Rate   load_gl load_glless   perl
+ load_gl     74.36+-0.61/s        --      -50.5% -87.7%
+ load_glless 150.15+-0.8/s 101.9+-2%          -- -75.1%
+ perl         603.8+-3.8/s 712+-8.4% 302.1+-3.3%     --
  
  Average times:
-   perl       :     1.5319ms
-   load_glless:     6.8451ms
-   load_gl    :    13.2855ms
+   perl       :     1.6562ms
+   load_glless:     6.6600ms
+   load_gl    :    13.4481ms
 
 =for Pod::Coverage .+
 
